Good news is that getting past the failed to start shell issue isn't that 
bad, mostly transitive dependency changes (man there are times I love 
maven, mostly when I'm not using it...), but also losing the ability to run 
tests in IE8, IE11. Not sure that is a great loss.

Bad news is that it doesn't help - the same errors still happen, the same 
tests still fail.

Patch from current HEAD and logs of failures in 
GWTTestCaseSetupTearDownTest (the only one I ran as a representative 
example) are attached if anyone wants to eyeball it quick, see if I did 
anything too dumb.

With that out of the way, I'll try to understand the root issue, see if I 
can't figure out what has changed in HtmlUnit that causes this. Failing 
that, I'll roll back to the older jetty/htmlunit, and hopefully that will 
jog something loose in my head.

-- 
You received this message because you are subscribed to the Google Groups "GWT 
Contributors" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to [email protected].
To view this discussion on the web visit 
https://groups.google.com/d/msgid/google-web-toolkit-contributors/4bd5c079-c06a-46ae-8f92-fdb89161dccd%40googlegroups.com.
For more options, visit https://groups.google.com/d/optout.
Testsuite: com.google.gwt.junit.client.GWTTestCaseSetupTearDownTest
Tests run: 7, Failures: 3, Errors: 2, Skipped: 0, Time elapsed: 28.256 sec
------------- Standard Output ---------------
Logging initialized @1669ms
jetty-9.2.z-SNAPSHOT
Started 
c.g.g.j.@358ee631{/,file:/Users/colin/workspace/gwt/build/out/user/test/web-htmlunit/www/,AVAILABLE}{/Users/colin/workspace/gwt/build/out/user/test/web-htmlunit/www}
Started ServerConnector@2448bc21{HTTP/1.1}{0.0.0.0:64644}
Started @2300ms
warning: message=[RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.] sourceName=[script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)] line=[56] lineSource=[null] lineOffset=[0]
warning: message=[RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.] sourceName=[script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)] line=[25] lineSource=[null] lineOffset=[0]
warning: message=[RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.] sourceName=[script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)] line=[220] lineSource=[null] lineOffset=[0]
warning: message=[RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.] sourceName=[script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)] line=[63] lineSource=[null] lineOffset=[0]
runtimeError: message=[Java class 
"com.gargoylesoftware.htmlunit.ScriptException" has no public instance field or 
method named "__java$exception".] sourceName=[script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)] line=[159] lineSource=[null] lineOffset=[0]
warning: message=[RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.] sourceName=[script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)] line=[63] lineSource=[null] lineOffset=[0]
Caught script exception
======= EXCEPTION START ========
Exception class=[net.sourceforge.htmlunit.corejs.javascript.JavaScriptException]
com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346)
        at 
com.gargoylesoftware.htmlunit.javascript.JavaScriptEngine$HtmlUnitContextAction.run(JavaScriptEngine.java:894)
        at 
net.sourceforge.htmlunit.corejs.javascript.Context.call(Context.java:637)
        at 
net.sourceforge.htmlunit.corejs.javascript.ContextFactory.call(ContextFactory.java:518)
        at 
com.gargoylesoftware.htmlunit.javascript.JavaScriptEngine.callFunction(JavaScriptEngine.java:823)
        at 
com.gargoylesoftware.htmlunit.javascript.JavaScriptEngine.callFunction(JavaScriptEngine.java:795)
        at 
com.gargoylesoftware.htmlunit.html.HtmlPage.executeJavaScriptFunction(HtmlPage.java:2504)
        at 
com.gargoylesoftware.htmlunit.html.HtmlPage.executeJavaScriptFunction(HtmlPage.java:2497)
        at 
com.gargoylesoftware.htmlunit.javascript.background.JavaScriptFunctionJob.runJavaScript(JavaScriptFunctionJob.java:52)
        at 
com.gargoylesoftware.htmlunit.javascript.background.JavaScriptExecutionJob.run(JavaScriptExecutionJob.java:102)
        at 
com.gargoylesoftware.htmlunit.javascript.background.JavaScriptJobManagerImpl.runSingleJob(JavaScriptJobManagerImpl.java:424)
        at 
com.gargoylesoftware.htmlunit.javascript.background.DefaultJavaScriptExecutor.run(DefaultJavaScriptExecutor.java:155)
        at java.lang.Thread.run(Thread.java:745)
Caused by: net.sourceforge.htmlunit.corejs.javascript.JavaScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346)
        at 
net.sourceforge.htmlunit.corejs.javascript.Interpreter.interpretLoop(Interpreter.java:1015)
        at 
net.sourceforge.htmlunit.corejs.javascript.Interpreter.interpret(Interpreter.java:800)
        at 
net.sourceforge.htmlunit.corejs.javascript.InterpretedFunction.call(InterpretedFunction.java:105)
        at 
net.sourceforge.htmlunit.corejs.javascript.ContextFactory.doTopCall(ContextFactory.java:416)
        at 
com.gargoylesoftware.htmlunit.javascript.HtmlUnitContextFactory.doTopCall(HtmlUnitContextFactory.java:322)
        at 
net.sourceforge.htmlunit.corejs.javascript.ScriptRuntime.doTopCall(ScriptRuntime.java:3264)
        at 
com.gargoylesoftware.htmlunit.javascript.JavaScriptEngine$4.doRun(JavaScriptEngine.java:816)
        at 
com.gargoylesoftware.htmlunit.javascript.JavaScriptEngine$HtmlUnitContextAction.run(JavaScriptEngine.java:879)
        ... 11 more
JavaScriptException value = [object Object]
== CALLING JAVASCRIPT ==
  function () {
      var a;
      uA[a = ++vA] = null;
      throw wA[a] = ZF + wE, b;
  }
======= EXCEPTION END ========
------------- ---------------- ---------------
------------- Standard Error -----------------
The -out option is deprecated. This option will be removed in future GWT 
release and will throw an error if it is still used. Please use -war option 
instead.
Could not find the GWT compiler jarfile. Serialization errors might occur when 
accessing the persistent unit cache.
RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.
RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.
RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.
RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.
RHINO USAGE WARNING: Missed Context.javaToJS() conversion:
Rhino runtime detected object com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346) of class com.gargoylesoftware.htmlunit.ScriptException 
where it expected String, Number, Boolean or Scriptable instance. Please check 
your code for missing Context.javaToJS() call.
------------- ---------------- ---------------

Testcase: test_assertAllSetUpTearDowns took 27.521 sec
        Caused an ERROR
null
java.util.NoSuchElementException
        at java.lang.Throwable.Throwable(Throwable.java:60)
        at java.lang.RuntimeException.RuntimeException(Exception.java:25)
        at 
java.util.NoSuchElementException.NoSuchElementException(NoSuchElementException.java:25)
        at 
javaemul.internal.InternalPreconditions.checkCriticalElement(InternalPreconditions.java:241)
        at java.util.ArrayList$1.$next(InternalPreconditions.java:223)
        at 
com.google.gwt.junit.client.GWTTestCaseSetupTearDownTest.test_assertAllSetUpTearDowns(GWTTestCaseSetupTearDownTest.java:135)
        at Unknown.anonymous(GWTTestMetadataImpl.java:8)
        at 
com.google.gwt.junit.client.impl.GWTTestAccessor.$invoke(GWTTestAccessor.java:35)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$executeTestMethod(GWTRunner.java:226)
        at 
com.google.gwt.junit.client.GWTTestCase.$doRunTest(GWTTestCase.java:157)
        at com.google.gwt.junit.client.GWTTestCase.$runBare(TestCase.java:59)
        at 
com.google.gwt.junit.client.GWTTestCase.$__doRunTest(GWTTestCase.java:115)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$runTest(GWTRunner.java:302)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$doRunTest(GWTRunner.java:235)
        at 
com.google.gwt.junit.client.impl.GWTRunner$TestBlockListener.$onSuccess(GWTRunner.java:106)
        at 
com.google.gwt.junit.client.impl.GWTRunner$InitialResponseListener.$onSuccess(GWTRunner.java:61)
        at 
com.google.gwt.junit.client.impl.GWTRunner$InitialResponseListener.onSuccess(GWTRunner.java:59)
        at 
com.google.gwt.user.client.rpc.impl.RequestCallbackAdapter.$onResponseReceived(RequestCallbackAdapter.java:232)
        at 
com.google.gwt.http.client.Request.$fireOnResponseReceived(Request.java:250)
        at 
com.google.gwt.http.client.RequestBuilder$1.onReadyStateChange(RequestBuilder.java:412)
        at Unknown.anonymous(XMLHttpRequest.java:329)
        at com.google.gwt.core.client.impl.Impl.apply(Impl.java:309)
        at com.google.gwt.core.client.impl.Impl.entry0(Impl.java:368)
        at Unknown.anonymous(Impl.java:78)

Testcase: testSetUpTearDown took 0.024 sec
Testcase: testSetUpTearDownAsync took 0.025 sec
Testcase: testSetUpTearDownFail took 0.051 sec
        FAILED
failed
junit.framework.AssertionFailedError: failed
        at java.lang.Throwable.Throwable(Throwable.java:73)
        at java.lang.Error.Error(Error.java:30)
        at java.lang.AssertionError.AssertionError(AssertionError.java:51)
        at 
junit.framework.AssertionFailedError.AssertionFailedError(AssertionFailedError.java:27)
        at 
com.google.gwt.junit.client.GWTTestCaseSetupTearDownTest.testSetUpTearDownFail(GWTTestCaseSetupTearDownTest.java:81)
        at Unknown.anonymous(GWTTestMetadataImpl.java:13)
        at 
com.google.gwt.junit.client.impl.GWTTestAccessor.$invoke(GWTTestAccessor.java:35)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$executeTestMethod(GWTRunner.java:226)
        at 
com.google.gwt.junit.client.GWTTestCase.$doRunTest(GWTTestCase.java:157)
        at com.google.gwt.junit.client.GWTTestCase.$runBare(TestCase.java:59)
        at 
com.google.gwt.junit.client.GWTTestCase.$__doRunTest(GWTTestCase.java:115)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$runTest(GWTRunner.java:302)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$doRunTest(GWTRunner.java:235)
        at 
com.google.gwt.junit.client.impl.GWTRunner$TestBlockListener.$onSuccess(GWTRunner.java:106)
        at 
com.google.gwt.junit.client.impl.GWTRunner$TestBlockListener.onSuccess(GWTRunner.java:100)
        at 
com.google.gwt.user.client.rpc.impl.RequestCallbackAdapter.$onResponseReceived(RequestCallbackAdapter.java:232)
        at 
com.google.gwt.http.client.Request.$fireOnResponseReceived(Request.java:250)
        at 
com.google.gwt.http.client.RequestBuilder$1.onReadyStateChange(RequestBuilder.java:412)
        at Unknown.anonymous(XMLHttpRequest.java:329)
        at com.google.gwt.core.client.impl.Impl.apply(Impl.java:309)
        at com.google.gwt.core.client.impl.Impl.entry0(Impl.java:368)
        at Unknown.anonymous(Impl.java:78)

Testcase: testSetUpTearDownFailSync took 0.056 sec
        FAILED
testSetUpTearDownFailAsync
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync
        at java.lang.Throwable.Throwable(Throwable.java:73)
        at java.lang.Error.Error(Error.java:30)
        at java.lang.AssertionError.AssertionError(AssertionError.java:51)
        at 
junit.framework.AssertionFailedError.AssertionFailedError(AssertionFailedError.java:27)
        at 
com.google.gwt.junit.client.GWTTestCaseSetupTearDownTest.testSetUpTearDownFailSync(GWTTestCaseSetupTearDownTest.java:91)
        at Unknown.anonymous(GWTTestMetadataImpl.java:12)
        at 
com.google.gwt.junit.client.impl.GWTTestAccessor.$invoke(GWTTestAccessor.java:35)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$executeTestMethod(GWTRunner.java:226)
        at 
com.google.gwt.junit.client.GWTTestCase.$doRunTest(GWTTestCase.java:157)
        at com.google.gwt.junit.client.GWTTestCase.$runBare(TestCase.java:59)
        at 
com.google.gwt.junit.client.GWTTestCase.$__doRunTest(GWTTestCase.java:115)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$runTest(GWTRunner.java:302)
        at 
com.google.gwt.junit.client.impl.GWTRunner.$doRunTest(GWTRunner.java:235)
        at 
com.google.gwt.junit.client.impl.GWTRunner$TestBlockListener.$onSuccess(GWTRunner.java:106)
        at 
com.google.gwt.junit.client.impl.GWTRunner$TestBlockListener.onSuccess(GWTRunner.java:100)
        at 
com.google.gwt.user.client.rpc.impl.RequestCallbackAdapter.$onResponseReceived(RequestCallbackAdapter.java:232)
        at 
com.google.gwt.http.client.Request.$fireOnResponseReceived(Request.java:250)
        at 
com.google.gwt.http.client.RequestBuilder$1.onReadyStateChange(RequestBuilder.java:412)
        at Unknown.anonymous(XMLHttpRequest.java:329)
        at com.google.gwt.core.client.impl.Impl.apply(Impl.java:309)
        at com.google.gwt.core.client.impl.Impl.entry0(Impl.java:368)
        at Unknown.anonymous(Impl.java:78)

Testcase: testSetUpTearDownFailAsync took 0.056 sec
        FAILED
testSetUpTearDownFailAsync
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync
        at java.lang.Throwable.Throwable(Throwable.java:73)
        at java.lang.Error.Error(Error.java:30)
        at java.lang.AssertionError.AssertionError(AssertionError.java:51)
        at 
junit.framework.AssertionFailedError.AssertionFailedError(AssertionFailedError.java:27)
        at 
com.google.gwt.junit.client.GWTTestCaseSetupTearDownTest$2.run(GWTTestCaseSetupTearDownTest.java:104)
        at com.google.gwt.user.client.Timer.fire(Timer.java:135)
        at Unknown.anonymous(Timer.java:139)
        at com.google.gwt.core.client.impl.Impl.apply(Impl.java:309)
        at com.google.gwt.core.client.impl.Impl.entry0(Impl.java:361)
        at Unknown.anonymous(Impl.java:78)

Testcase: testSetUpTearDownTimeout took 0.053 sec
        Caused an ERROR
com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346)
java.lang.JsException: com.gargoylesoftware.htmlunit.ScriptException: 
junit.framework.AssertionFailedError: testSetUpTearDownFailAsync (script in 
http://localhost:64644/com.google.gwt.junit.JUnit.JUnit/junit.html from (-1, 
-1) to (-1, -1)#346)

diff --git a/dev/build.xml b/dev/build.xml
index acc8422..625e2fc 100755
--- a/dev/build.xml
+++ b/dev/build.xml
@@ -94,18 +94,18 @@
           <include name="tomcat/tomcat-annotations-api-8.0.28.jar"/>
           <include name="apache/commons/commons-collections-3.2.2.jar"/>
           <!-- htmlunit dependencies not already included: BEGIN -->
-          <include name="apache/http/httpclient-4.5.1.jar"/>
-          <include name="apache/http/httpcore-4.4.4.jar"/>
-          <include name="apache/http/httpmime-4.5.1.jar"/>
+          <include name="apache/http/httpclient-4.5.3.jar"/>
+          <include name="apache/http/httpcore-4.4.6.jar"/>
+          <include name="apache/http/httpmime-4.5.3.jar"/>
           <include name="apache/james/apache-mime4j-0.6.jar"/>
           <include name="apache/commons/commons-codec-1.10.jar"/>
           <include name="apache/commons/commons-io-2.4.jar"/>
           <include name="apache/commons/commons-lang3-3.4.jar"/>
           <include name="apache/commons/commons-logging-1.2.jar"/>
           <include name="cssparser/cssparser-0.9.18.jar"/>
-         <include name="htmlunit/htmlunit-2.19/htmlunit-2.19.jar"/>
-         <include name="htmlunit/htmlunit-2.19/htmlunit-core-js-2.15.jar"/>
-          <include name="nekohtml/nekohtml-1.9.22.jar"/>
+         <include name="htmlunit/htmlunit-2.27/htmlunit-2.27.jar"/>
+         <include name="htmlunit/htmlunit-2.27/htmlunit-core-js-2.27.jar"/>
+          <include name="nekohtml/nekohtml-2.27.jar"/>
           <include name="cup/java-cup-11a.jar"/>
           <include name="xalan/xalan-2.7.1-nocup.jar"/>
           <include name="xerces/xerces-2_11_0/serializer-2.7.1.jar"/>
@@ -154,19 +154,19 @@
           <zipfileset
               src="${gwt.tools.lib}/apache/commons/commons-collections-3.2.2.jar"/>
           <!-- htmlunit dependencies not already included: BEGIN -->
-          <zipfileset src="${gwt.tools.lib}/apache/http/httpclient-4.5.1.jar"/>
-          <zipfileset src="${gwt.tools.lib}/apache/http/httpcore-4.4.4.jar"/>
-          <zipfileset src="${gwt.tools.lib}/apache/http/httpmime-4.5.1.jar"/>
+          <zipfileset src="${gwt.tools.lib}/apache/http/httpclient-4.5.3.jar"/>
+          <zipfileset src="${gwt.tools.lib}/apache/http/httpcore-4.4.6.jar"/>
+          <zipfileset src="${gwt.tools.lib}/apache/http/httpmime-4.5.3.jar"/>
           <zipfileset src="${gwt.tools.lib}/apache/james/apache-mime4j-0.6.jar"/>
           <zipfileset src="${gwt.tools.lib}/apache/commons/commons-codec-1.10.jar"/>
           <zipfileset src="${gwt.tools.lib}/apache/commons/commons-io-2.4.jar"/>
           <zipfileset src="${gwt.tools.lib}/apache/commons/commons-lang3-3.4.jar"/>
           <zipfileset src="${gwt.tools.lib}/apache/commons/commons-logging-1.2.jar"/>
           <zipfileset src="${gwt.tools.lib}/cssparser/cssparser-0.9.18.jar"/>
-          <zipfileset src="${gwt.tools.lib}/htmlunit/htmlunit-2.19/htmlunit-2.19.jar"/>
+          <zipfileset src="${gwt.tools.lib}/htmlunit/htmlunit-2.27/htmlunit-2.27.jar"/>
           <zipfileset
-              src="${gwt.tools.lib}/htmlunit/htmlunit-2.19/htmlunit-core-js-2.15.jar"/>
-          <zipfileset src="${gwt.tools.lib}/nekohtml/nekohtml-1.9.22.jar"/>
+              src="${gwt.tools.lib}/htmlunit/htmlunit-2.27/htmlunit-core-js-2.27.jar"/>
+          <zipfileset src="${gwt.tools.lib}/nekohtml/nekohtml-2.27.jar"/>
           <zipfileset src="${gwt.tools.lib}/cup/java-cup-11a.jar"/>
           <zipfileset src="${gwt.tools.lib}/xalan/xalan-2.7.1-nocup.jar"/>
           <zipfileset src="${gwt.tools.lib}/xerces/xerces-2_11_0/serializer-2.7.1.jar"/>
diff --git a/user/src/com/google/gwt/core/Core.gwt.xml b/user/src/com/google/gwt/core/Core.gwt.xml
index cff43a5..16b8c4d 100644
--- a/user/src/com/google/gwt/core/Core.gwt.xml
+++ b/user/src/com/google/gwt/core/Core.gwt.xml
@@ -92,7 +92,7 @@
      - Do not trap anything (legacy behavior) (IGNORE)
   -->
   <define-property name="gwt.uncaughtexceptionhander.windowonerror" values="IGNORE, REPORT, REPORT_IF_NO_HANDLER" />
-  <set-property name="gwt.uncaughtexceptionhander.windowonerror" value="IGNORE"/>
+  <set-property name="gwt.uncaughtexceptionhander.windowonerror" value="REPORT_IF_NO_HANDLER"/>
 
   <!-- To support legacy logging flags -->
   <inherits name="com.google.gwt.logging.LogImpl"/>
diff --git a/user/src/com/google/gwt/junit/RunStyleHtmlUnit.java b/user/src/com/google/gwt/junit/RunStyleHtmlUnit.java
index 7daf264..653d17b 100644
--- a/user/src/com/google/gwt/junit/RunStyleHtmlUnit.java
+++ b/user/src/com/google/gwt/junit/RunStyleHtmlUnit.java
@@ -24,7 +24,6 @@ import com.gargoylesoftware.htmlunit.AlertHandler;
 import com.gargoylesoftware.htmlunit.BrowserVersion;
 import com.gargoylesoftware.htmlunit.FailingHttpStatusCodeException;
 import com.gargoylesoftware.htmlunit.IncorrectnessListener;
-import com.gargoylesoftware.htmlunit.InteractivePage;
 import com.gargoylesoftware.htmlunit.OnbeforeunloadHandler;
 import com.gargoylesoftware.htmlunit.Page;
 import com.gargoylesoftware.htmlunit.ScriptException;
@@ -108,21 +107,21 @@ public class RunStyleHtmlUnit extends RunStyle {
       webClient.setJavaScriptErrorListener(new JavaScriptErrorListener() {
 
         @Override
-        public void loadScriptError(InteractivePage htmlPage, URL scriptUrl,
+        public void loadScriptError(HtmlPage htmlPage, URL scriptUrl,
             Exception exception) {
             treeLogger.log(TreeLogger.ERROR,
               "Load Script Error: " + exception, exception);
         }
 
         @Override
-        public void malformedScriptURL(InteractivePage htmlPage, String url,
+        public void malformedScriptURL(HtmlPage htmlPage, String url,
             MalformedURLException malformedURLException) {
           treeLogger.log(TreeLogger.ERROR,
               "Malformed Script URL: " + malformedURLException.getLocalizedMessage());
         }
 
         @Override
-        public void scriptException(InteractivePage htmlPage,
+        public void scriptException(HtmlPage htmlPage,
             ScriptException scriptException) {
           treeLogger.log(TreeLogger.DEBUG,
               "Script Exception: " + scriptException.getLocalizedMessage() +
@@ -130,7 +129,7 @@ public class RunStyleHtmlUnit extends RunStyle {
         }
 
         @Override
-        public void timeoutError(InteractivePage htmlPage, long allowedTime,
+        public void timeoutError(HtmlPage htmlPage, long allowedTime,
             long executionTime) {
           treeLogger.log(TreeLogger.ERROR,
               "Script Timeout Error " + executionTime + " > " + allowedTime);
@@ -188,7 +187,7 @@ public class RunStyleHtmlUnit extends RunStyle {
     public void initialize(WebWindow webWindow) {
       // Hook in the hosted-mode plugin after initializing the JS engine.
       super.initialize(webWindow);
-      Window window = (Window) webWindow.getScriptObject();
+      Window window = (Window) webWindow.getScriptableObject();
       window.defineProperty("__gwt_HostedModePlugin",
           new HostedModePluginObject(this, logger), ScriptableObject.READONLY);
     }
@@ -200,10 +199,8 @@ public class RunStyleHtmlUnit extends RunStyle {
   static {
     // “Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.71 Safari/537.36 Edge/12.0″
     addBrowser(BrowserVersion.EDGE, "safari");
-    addBrowser(BrowserVersion.FIREFOX_38, "gecko1_8");
+    addBrowser(BrowserVersion.FIREFOX_52, "gecko1_8");
     addBrowser(BrowserVersion.CHROME, "safari");
-    addBrowser(BrowserVersion.INTERNET_EXPLORER_8, "ie8");
-    addBrowser(BrowserVersion.INTERNET_EXPLORER_11, "gecko1_8");
   }
 
   private static void addBrowser(BrowserVersion browser, String userAgent) {
@@ -239,8 +236,8 @@ public class RunStyleHtmlUnit extends RunStyle {
   @Override
   public int initialize(String args) {
     if (args == null || args.length() == 0) {
-      // If no browsers specified, default to Firefox 38.
-      args = "FF38";
+      // If no browsers specified, default to Firefox 52.
+      args = "FF52";
     }
     Set<BrowserVersion> browserSet = new HashSet<BrowserVersion>();
     Set<String> userAgentSet = new HashSet<String>();

Reply via email to